# WindML

![](images/logo.png)

Refreshingly Lightweight Machine Learning (using only numpy). models include conditional-character-RNN, Transformer and a Direct Feedback Alignment NN and other one-shot models like extreme learning machines or matrix factorisation retrieval-based classifiers (for a model-free alternative). 

## ChangeLog
- 0.2.3 allow epochs to be specified by user in rnn
- 0.2.2 bug fix. also removing fixed bos, eos, etc tokens and allowing to be set dynamically
- 0.2.1 adding bos, eos, pad token ids and updating epochs
- 0.2.0 token-level rnn added
- 0.1.3 bug fix: adding init file
- 0.1.2 char-rnn can now take context vector for conditional generation
- 0.1.1 refactor char-rnn code
- 0.1.0 added char-rnn model
- 0.0.2 bug fix: adding init files to directories
- 0.0.1 initial release